-- -----------------------------------------------------------------------------
--
--    Licensed Materials - Property of IBM
--    5698-B34  Copyright IBM Corp. 2008, 2011
--    All rights reserved.
--
--    US Government Users Restricted Rights - Use, duplication or
--    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
--	  RESTRICTED RIGHTS:
--
--	  This file may have been supplied under a license.
--	  It may be used, disclosed, and/or copied only as permitted
--	  under such license agreement.  Any copy must contain the
--	  above copyright notice and this restricted rights notice.
--	  Use, copying, and/or disclosure of the file is strictly
--	  prohibited unless otherwise provided in the license agreement.
--
--    File: tivoli_eif/zos_files/zOSEventSupport.sql, OMNIbus, EventPump422
--    SID: 1.18.1.1
--    Date Modified: 11/11/23 05:42:55
--
--    Desription:
--       This sql file is used to modify the alert.status table structure by 
--       adding several columns and some automation trigger code to to the 
--       alerts.status table required to support incoming z/OS events.
--       This file is applied to the Collection (primary) server in a typical 
--       3-tier ESF configuration.
--
--    Change History:
--    YY/MM/DD            Description
--    08/09/26            Initial  IBM Tivoli Event Pump for z/OS V4.2.0
--    08/10/13            Fixed depulication issue
--    09/01/01            $02:FVB: TWS data source related changes
--    09/03/24            $03:RAR: Removed Tally count increatment,
--                                 default trigger updating
--    09/05/20            $04:DB : RMF data source related changes
--    09/07/15            $05:DB : CPSM data source related changes
--    10/08/09            $06:RAR: New DB2 events using product prefix GPZ
--    10/08/10            $07:TIS: Storage data source SMS related changes
--    10/06/10            $08:RAR: remove @07 change IDs and syntax error 
--                                 SMS_FALSE
--    10/12/10            $09:RAR: Change event id TWS_CP UPDATED to 
--                                 TWS_CPUPDATED
--    10/13/10            $10:RAR: Remove $09 update
--    11/03/29            $11,OA35651,VON,RMF events mapping
--
-- -----------------------------------------------------------------------------
-- Add additional z/OS columns to the status table.
--
-- These columns are used for resource identification.
-- -----------------------------------------------------------------------------

alter table alerts.status add column BSM_Identity varchar(1024);
go

alter table alerts.status add column BSM_SubIdentity varchar(1024);
go

-- -----------------------------------------------------------------------------
-- Add additional z/OS columns to the status table.
--
-- These columns are used for z/OS event attributes.
--
-- -----------------------------------------------------------------------------

alter table alerts.status add column ZOS_SequenceNo varchar(64);
go

alter table alerts.status add column ZOS_ClassID varchar(64);
go

alter table alerts.status add column ZOS_EventID varchar(64);
go

alter table alerts.status add column ZOS_MsgState varchar(64);
go

alter table alerts.status add column ZOS_Action varchar(32);
go

alter table alerts.status add column ZOS_Format varchar(64);
go

alter table alerts.status add column ZOS_IsUserSeverity Integer;
go

alter table alerts.status add column ZOS_ResourceName varchar(1024);
go

alter table alerts.status add column ZOS_SubResourceName varchar(1024);
go

alter table alerts.status add column ZOS_SubResourceType varchar(64);
go

-- -----------------------------------------------------------------------------
-- Create a Message event severity and state lookup table.
-- -----------------------------------------------------------------------------

CREATE TABLE alerts.zos_severity_msgstate_lookup PERSISTENT(LookupID Incr PRIMARY KEY NODEFAULT NOMODIFY, EventID VarChar(50) PRIMARY KEY NODEFAULT NOMODIFY, Severity Integer, MsgState VarChar(128), IsMessage Integer PRIMARY KEY NODEFAULT NOMODIFY);
go

delete from alerts.zos_severity_msgstate_lookup;
go

insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE793I OFFLINE,BOXED', 5, 'OFFLINE,BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE793I PENDING OFFLINE,BOXED', 3, 'P. OFF,BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IGD010I DISABLE,NEW', 3, 'DISABLE,NEW', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IGD010I QUIESCE,NEW', 3, 'QUIESCE,NEW', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\$HASP050', 3, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\$HASP095', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\$HASP547', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+ACCALRT', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+DFHSI1517', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+DFHZN211', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+ISC00001', 3, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+ISC00002', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^\\+MCM', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90080', 3, 'RO', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90081', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90081', 5, 'STOP', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90082', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90083', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90084', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90086', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90086', 3, 'UT', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90088', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90089', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90089', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C9008E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90092', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90093', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90096', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C90097', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900A0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900A1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900A3', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900A5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900A9', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900AB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900AD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900AE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900BA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900BC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900C0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900C1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900C5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900CB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900RW', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00C900RW', 0, 'RW', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^00F30056', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AACTSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABCLSPR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABENDING', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABGAMR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABGAXR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABND', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ABUF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACBH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACC0225', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACC0246', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACC1001', 5, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACC1002', 5, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCALRT', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS01', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS02', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS22.ENA.OPE', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS23', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS23.UNE.CLO', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS24', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS24.DIS.CLO', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS24.DIS.OPE', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS24.ENA.CLO', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACCESS24.UNE.OPE', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACEA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ACTIVE', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADARPSSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADARSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADAWPSSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADAWSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADBW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADCOM12R', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADCOM12S', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADCPUT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADCPUTP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDB2ETT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDBCPUT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Added', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDSELRQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDSELSR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDSSRSR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADDSTOTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADIFICAL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADIOPSSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADIOSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADIOSUST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADLLPSSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADLLSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADMB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADRECETT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADRGPRIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADROL12R', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADROL12S', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADSTPSSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADSTSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADSTSUST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADSU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTDDL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTIMDLK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTOTPFL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTSUSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTSUSCP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTSUST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTSUSTP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTWTAP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADTWTDB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ADWTCL7T', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AELCOMCT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AEPC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AFRE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AHIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AIDS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALCLKET', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALIAS .*', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALLOC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALLPSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALMD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALRSUSLL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ALRSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AmbiguousServer', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AMFS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AMSG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AMXP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AMXT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTA8004I', 0, 'Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTA8101I', 0, 'Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTA8124I', 3, 'Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTB5010E', 3, 'Initialization Failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTB8000I', 0, 'Initialization Started', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTB8001I', 0, 'Initialization Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC5402E', 5, 'Hold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC5403E', 5, 'Hold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8400I', 0, 'Coupled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8401I', 3, 'Uncoupled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8402W', 5, 'Hold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8406I', 0, 'Interlocked', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8407I', 3, 'Interlock delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8410I', 3, 'Uncoupled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8411I', 0, 'Not on Hold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTC8414W', 3, 'Not-Interlocked', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTD8025I', 3, 'Not in session', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTD8103I', 3, 'Not in session', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTD8116I', 3, 'Not in Session', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTE8008I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTE8106I', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTI8023I', 0, 'Copy', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTI8024I', 0, 'Duplex', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTI8121I', 0, 'Restarted', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTR8102I', 0, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTS8100I Restarted', 0, 'Restarted', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTS8100I Started', 0, 'Started', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTV8107I', 3, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTV8109I', 3, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTV8110I', 5, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTV8114I', 5, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTX8120I Duplex', 0, 'Duplex', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ANTX8120I Suspended', 5, 'Suspended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ABENDING', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ACTIVE', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ASSIST', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.AUTODOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.AUTOTERM', 0, 'Stopping', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.AVAILABLE', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.AWAITING', 3, 'Awaiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.BREAKING', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.BROKEN', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.CTLDOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.DEGRADED', 3, 'Degraded', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.DENIED', 5, 'Denied', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.DOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ENDED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ENDING', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.EXTSTART', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.FALLBACK', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.HALFDOWN', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.HALTED', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.HARDDOWN', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.INACTIVE', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.INAUTO', 3, 'Inauto', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.INHIBITED', 5, 'Inhibited', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.MOVED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.PROBLEM', 5, 'Problem', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.RESTART', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.RUNNING', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.SATISFACTORY', 0, 'Satisfactory', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.SOFTDOWN', 0, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STANDBY', 3, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STARTED', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STARTED2', 3, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STARTING', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STOPPED', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STOPPING', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.STUCK', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.SYSGONE', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.UNKNOWN', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.WASAVAILABLE', 3, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOF571I.ZOMBIE', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^APLKSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0001I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0002I', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0008I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0016I', 5, 'Shutdown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0027I', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0033E', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0038I', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0046I', 0, 'Restart', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0047I', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0048I', 3, 'Restart', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0061I', 3, 'Shutdown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0517I', 0, 'Secondary active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0518I', 0, 'Secondary inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0520I', 0, 'Primary active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0521I', 0, 'Primary inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0526I', 0, 'Cleanup active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0527I', 0, 'Cleanup inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0530I', 0, 'Level1 active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0531I', 0, 'Level1 inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0532I', 3, 'Level1 failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0556I', 3, 'Failed restart', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0580I', 0, 'Interval active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0581I', 0, 'Interval inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0620I', 0, 'Auto dump active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0621I', 0, 'Auto dump inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0625I', 3, 'Auto dump failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0628I', 0, 'Auto expiration active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0629I', 0, 'Auto expiration inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0630I', 0, 'Table creation active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0631I', 0, 'Table creation inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0632I', 3, 'Table creation failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0634I', 3, 'Auto dump failed restart', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0648I', 0, 'VTOC deletion active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0649I', 0, 'VTOC deletion inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0717I', 3, 'Auto backup failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0720I', 0, 'Auto backup active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0721I', 0, 'Auto backup inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0735I', 0, 'MDS backup active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0736I', 0, 'MDS backup inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0740I', 0, 'CDS backup active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0741I', 0, 'CDS backup inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0830I', 0, 'Recycle active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0831I', 0, 'Recycle inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0835I', 3, 'Recycle failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0909E', 3, 'Over threshold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0910E', 5, 'Full', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC0911E', 3, 'Over threshold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC1010I', 3, 'User request failed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6022I', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6024I', 0, 'Secondary AS active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6027I', 3, 'Secondary AS inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6030I', 3, 'Secondary AS active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6032E', 3, 'Secondary AS inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6054I', 0, 'Abackup active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6055I', 0, 'Abackup inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6102I', 0, 'Arecover active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6103I', 0, 'Arecover inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARC6398E', 3, 'ABAR stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARCM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARCV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AREA..*', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ARTTERM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASABNOTM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASCDCL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASCDML', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASER', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0101', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0204', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0205', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0208', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0209', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0210', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0212', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0214', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0215', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0220', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASI.0502', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASIUD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASIUPLOAD.FAIL', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASMI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASNORMTM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ASSIST', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AuthFail', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AUTHFAIL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AUTODOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AUTOTERM', 0, 'Stopping', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0001I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0002I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0003E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0004I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0005I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0006E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0007I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0008I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0009E', 3, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0015I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0019I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0020I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0075E', 5, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0102W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0103W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0104E', 5, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0138W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0139W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOO0140E', 5, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0001I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0002I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0003E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0004I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0005I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0006E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0007I', 0, 'Initializing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0008I', 0, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0009E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0016I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0020I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0021I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0199E', 5, 'Stopped', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0377W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0378W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0379E', 5, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0575W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0576W', 3, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BBOU0577E', 5, 'Waiting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Beaconing', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BMAX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BMTH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BPE0009I.HWS', 5, 'Down', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BREAKING', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BROKEN', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BUSYI .*', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^BXPN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CA7.UNKNOWN.OS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CA7MISSINGSIRD-11', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CCB011W.*', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CCB011W.VTSSF', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CFREBUILD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CICT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CLHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CLLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Cmd', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CMHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CMLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CMXP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CMXT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^COMT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^COMW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CONTINUE.PENDING', 3, 'Continue Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEDCSTA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEDPSTA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEFWSTA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEHBYPP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEHINHP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEHIOR', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPELCHIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPELFWTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPELREAD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPELRHIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPELWHIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPEPNSTA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPUA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0008W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0009W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0014E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0018E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0019E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0020I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0021I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0111W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0200I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0205E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CQS0242E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CRHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CRLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0020I.OM', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0020I.RM', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0020I.SCI', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0021I.OM', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0021I.RM', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL0021I.SCI', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL2021E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL2030I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL2040I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL3011W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL3012W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL3013W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSL3110E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CSVC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CTHD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CTLDOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CUNIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CUOW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DB2.SUBSYSTEM.DOWN', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DB2.SUBSYSTEM.UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DBMN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DBON', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DBS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DBUP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DBWE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DCMN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DDFS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DDHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DDLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DEADLOCK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Delay', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Deleted', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Dev', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Device', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFHAC2236', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFHFC0200', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFHFC0201', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS039A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS039A', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0414I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0415I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0737A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0800I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0832I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0840I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0842I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0844I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0845I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0850W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS0851W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS1194I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2000I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2011I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2013', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2014', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2015', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2021', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2027I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS206', 5, 'Threshold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS207', 5, 'Threshold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS208', 5, 'Threshold', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2109', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2110A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2111I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2139', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2142', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2150A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2150I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2169I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2178I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2179I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2281I.LGMSG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2281I.SHMSG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2484I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2524I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2571I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2572I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2573I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2574I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2605I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2606I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2683A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS2684I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS269', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3201', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3202', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3203', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3205', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3206', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3207', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3208', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3209', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3212I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3213I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3217', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3218', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3220I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3221', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3222I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3223', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3224', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3225', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3226', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3227', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3228', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3229', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3230', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3231', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3232', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3233', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3234', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3235', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3236', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3237', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3238', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3239', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3240', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3241', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3245', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3246', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3247I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3256I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3257I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3258A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3259I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3260I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3262I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3263I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3264I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3265I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3492W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3607I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3611E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3611I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3611W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3643I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS3702I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS4161I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS4168I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS4169I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS551I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS552I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS554A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS625I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS838I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS843I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS970I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS983I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DFS998I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0006I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0007I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0100I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0210I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0211I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0212I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DGOV0213I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.ACTIVE', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.AQUIRED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.AVAILABLE', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CANCELLED', 5, 'Cancelled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CLOSED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CLOSEREQUEST', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CLOSING', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CONNECTED', 0, 'Connected', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CONNECTING', 0, 'Connecting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.CONTROLSHUT', 1, 'Controlshut', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.DIS.CLO', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.DIS.OPE', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.DISABLED', 3, 'Disabled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.DISCARDING ', 5, 'Discarding', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.DISCONNING', 0, 'Disconning', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.ENA.CLO', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.ENA.OPE', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.ENABLED', 0, 'Enabled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.FINALQUIESCE', 3, 'Finalquiesce', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.FIRSTINIT', 0, 'Firstinit', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.FIRSTQUIESCE', 0, 'Firstquiesce', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.FREEING', 0, 'Freeing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.INACTIVE', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.INITCOMPLETE', 0, 'Initcomplete', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.INITING', 0, 'Initing', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.INSERVICE', 0, 'Inservice', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.LOSTCMAS', 5, 'Lostcmas', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.LOSTCON', 3, 'Lostcon', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.LOSTMAS', 5, 'Lostmas', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.NOTAPPLIC', 3, 'Notapplic', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.NOTCONNECTED', 3, 'Notconnected', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.OBTAINING', 0, 'Obtaining', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.OPEN', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.OPENING', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.PENDINIT', 0, 'Pendinit', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.PENDRESOLVE', 0, 'Pendresolve', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.RELEASED', 0, 'Released', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.RESOLVING', 0, 'Resolving', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.SECONDINIT', 0, 'Secondinit', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.SHUTDOWN', 0, 'Shutdown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.STARTUP', 0, 'Startup', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.THIRDINIT', 0, 'Thirdinit', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.UNE.CLO', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.UNE.OPE', 3, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.UNRESOLVED', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISC.UNUSABLE', 5, 'Unusable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DLCL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DLDB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DLPB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DLTH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DLTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DMBE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DMBP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DMER', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DMFF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DNRS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DOWN', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHACTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHCONN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHDCUB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHDDPB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHDDVB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHDISC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHINTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHIOSQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHNRDY', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHPEND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHRSPT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPEHRSRV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DPRO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DRCV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DRDY', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0050', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0100', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0110', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0150', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0160', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0170', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0180', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0190', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0200', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0210', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0220', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0230', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0240', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0250', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0260', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0270', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0280', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0290', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0300', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0310', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0320', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0330', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0340', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0350', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0360', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0370', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0380', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0390', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0400', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0410', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0420', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0430', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0440', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0450', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0460', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0470', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0480', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0490', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0500', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0510', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0520', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0530', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0540', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0550', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0560', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0570', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0580', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0590', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0600', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0610', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0620', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0630', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0640', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0650', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0660', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0670', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0680', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0690', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0700', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0710', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0720', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0730', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0740', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0750', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0760', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0770', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0780', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0790', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0800', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0810', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0820', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0830', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0840', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0850', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0860', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0870', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0880', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0890', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0900', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0910', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0920', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0930', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0940', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0950', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0960', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0970', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0980', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS0990', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1000', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1050', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1100', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1110', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1150', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1160', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1170', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1180', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1200', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1230', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1240', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1250', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1260', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1400', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1410', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1420', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1430', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1440', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1450', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1480', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1500', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1510', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1520', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1530', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1540', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1550', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1560', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1570', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1580', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1590', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1600', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1610', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1620', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1630', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1640', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1650', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1660', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DS1670', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSAV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSEHALOC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSEHFRGI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELDSCB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELFREE', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELLEXT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELNOFE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELPCTF', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSELVIRS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSEXTENT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSIZ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN2001I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN2035I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN2036I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3002I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3010I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3011I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3012I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3013I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3014I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3015I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3017I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3020I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3021I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3104I', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN3201I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7501A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7504I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7505A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7506A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7508I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7510I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7511I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7512A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN7514I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSN9022I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB228I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB250E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB301E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB303E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB304I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB309I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB311I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB312I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB313I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB314I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB319A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB320I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB321I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB322I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB323I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB325A', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB330E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB335I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB340E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB350I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB351I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB352I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB601I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNB603I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNI010I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNI011I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNI012I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNI013I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNI014I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ004I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ013I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ014I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ030I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ100I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ103I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ105I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ106I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ107I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ108I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ109I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ110E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ111E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ112E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ113E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ114I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ115I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ124I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ125I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ126I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ128I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ153E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ372I', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ373I', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ409I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ419I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNJ420I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL004I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL006I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL008I', 5, 'Failure', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL013I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL014I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL015I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL016I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL017I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL018I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL033I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL035I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL066I', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL068I', 0, 'Available', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL400E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL401E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL402I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL403I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL404E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL405I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL406I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL408I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL409I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL410I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL411E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL412I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL413I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL414E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL417E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL418E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL420I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL425I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL432I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL433I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNL450I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNM005I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNP007I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNP008I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNP011I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNP012I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNR004I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNR035I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNR036I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT800I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT803I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT807I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT809E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT810E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNT811E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNV086E', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNX923I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSNX964I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0007I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0027I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0242I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0287W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0387I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP0387W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP1141I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP1145I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSP1146A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSPI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DSTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DUMP', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DupIP', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0050', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0100', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0110', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0150', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0160', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0170', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0180', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0190', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0200', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0210', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0220', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0240', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0250', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0260', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0270', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0280', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0290', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0300', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0310', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0320', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0330', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0340', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0350', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0360', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0370', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0380', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0390', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0400', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0410', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0420', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0430', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0440', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0450', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0460', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0470', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0480', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0490', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0500', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0510', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0520', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0560', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0590', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DW0600', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DWAT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXAB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR009I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR011I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR117I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR121I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR122E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR123E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR134E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR135E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR138E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR139E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR142E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR143I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR162I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR164E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR166E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DXR170I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DYPR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0040', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0510', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0520', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0530', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0540', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0550', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0560', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0570', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0590', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0600', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0610', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0620', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0630', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0640', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0650', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0660', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0670', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0680', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ0690', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1010', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1020', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1030', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1040', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1050', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1060', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1070', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1080', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1090', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1100', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1110', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1130', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DZ1140', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EDMPOOL', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EDMU', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ELAP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENDED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENDING', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENQC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENQP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENQW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENTU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENTW', 5, '', 0);
-- TWS data source entries removed     @02D5  EQQE036I  EQQE037I EQQE038I EQQE039I EQQQ515W
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Error', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ERROR.OPERATION', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESAV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESIZ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESOS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ESTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ETIM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EXPD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EXTSTART', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EZB4367E', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^EZB4369E', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FALLBACK', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Falling', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0006I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0007I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0210I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0211I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0212I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FPEV0213I', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT041', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT042', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT045', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT046', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10501', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10502', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10503', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10504', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10505', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10506', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10507', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT10508', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050B', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050C', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050D', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1050F', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1100A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1100B', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110A', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110B', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110C', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110D', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110F', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110G', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1110H', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1150', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1160', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1170', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1180', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1190', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1200', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1210', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT1220', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT517', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT518', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT539', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT540', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT541', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT542', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT543', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT544', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT545', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT546', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT547', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT604', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT605', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT606', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT607', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT608', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT609', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT610', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT611', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT612', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT613', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FT614', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FTP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FTPE100I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FTPS010I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FTPS020I', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Funct', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^FXFR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Generic', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GETP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GLOBAL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTM7911W', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTM7912D', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMAUAB', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMAUOF', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMAUON', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0020E', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0023I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0024E', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0026D', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0027E', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0036E', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0037E', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTMCP0038D', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GTRC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HALFDOWN', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HALTED', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HG2000', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HIPG', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HISY', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HITK', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSC0000I', 0, 'Up', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSC0100W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSC0110W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0212E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0222E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0227W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0250W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0252W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0254W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0260I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0270I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0280I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0282I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0284I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0286I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0727W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSD0730W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1100W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1101W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1105W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1110W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1115W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1205W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1210W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1215W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1220W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1305W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1310W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1315W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1320W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSO1325W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1405W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1410W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1415E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1420E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1430E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1470E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1475E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1480E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSP1485E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSR0800E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSR0810E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSR0890I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0700E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0712E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0714E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0727W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0730W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0746W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0761I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0770I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0771W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0775W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSS0785W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0901E', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0902E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0903E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0904E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0905E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0907E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0909E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0910E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0911E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0912E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0912W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^HWSX0913E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ICES', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ICLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IDBC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IDBK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IDBT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IDFR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IDNT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEA480E', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEA995I', 3, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE302I', 0, 'ONLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE303I', 3, 'OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE476I', 3, 'ONLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE794I', 3, 'PENDING OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE845I', 3, '"OFFLINE,P. BOXED"', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEE846I', 3, '"P. OFF,P. BOXED"', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF106I', 3, 'ONLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF281I', 5, '"OFFLINE,BOXED"', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF402I', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF403I', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF404I', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF450I', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF453I', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF480E', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF524I', 3, 'PENDING OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF696I', 5, 'NOT READY', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF771I OFFLINE', 3, 'OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEF771I PENDING OFFLINE', 3, 'PENDING OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IEFC452I', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^DISABLE IGD010I', 5, 'DISABLE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ENABLE IGD010I', 0, 'ENABLE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QUIESCE IGD010I', 5, 'QUIESCE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IGD07002I', 5, 'UNAVAILABLE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS$DBUG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS420I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS452I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS452I.DOWN', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS452I.UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS497I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS648', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS686', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS718I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS718I.NOK', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS719I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS743', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHS745E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHSBLK01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHSBPM01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHSBPM02', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IHSBSP01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ILHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ILLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMCN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMS.SUBSYSTEM.ABEND', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMS.SUBSYSTEM.DOWN', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMS.SUBSYSTEM.UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3534I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3535E', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3536I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3537I', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3538I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3539E', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3540I', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3541I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IMW3542E', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INAB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INAC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INACTIVE', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INDB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INDOUBT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INDOUBTDD', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^INTRV', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOERR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IORC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS000I', 3, 'IO ERROR', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS100I BOXED', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS100I OFFLINE', 5, 'OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS101I BOXED', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS101I FORCED OFFLINE', 5, 'FORCED OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS102I BOXED', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS102I FORCED OFFLINE', 5, 'FORCED OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS104I BOXED', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS104I FORCED OFFLINE', 5, 'FORCED OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS105I BOXED', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS105I FORCED OFFLINE', 5, 'FORCED OFFLINE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS109E', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS150I', 3, 'AVAILABLE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS151I', 3, 'UNAVAILABLE', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS152E', 5, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS153E', 3, '"BOXED,AVAILABLE"', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS451I', 3, 'BOXED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS600I', 3, 'STOPPED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IOS607I', 0, 'RESUMED', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRCS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRFC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRGC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRIN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRRC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRRU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRTP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IRTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ISHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ISLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IST020I', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ITWH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IWM032IQUIESCE', 5, 'Quiesced', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IWM032IRESUME', 0, 'Resumed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IXC402D', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^IXC409D', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^JCJS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^JCLERROR.*', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^JOBEND.NOTOK', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^JOBEND.OK', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^JOBSTART', 0, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Journal', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LALO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LATE.OPERATION', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LDMB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LinkChange', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LinkChange', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LKTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LKUS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LLBR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LLCH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LMGH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LMLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Log', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LOGN', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LOGSPACE', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LONG.DURATION', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^LSQA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MaintComplete', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MaintEnd', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MaintNotComplete', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MaintStart', 1, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Managed', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Marginal', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MAXP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MAXR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MAXT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MAXU', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MCNV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MDBT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MDBW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0001', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0002', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0003', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0011', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0012', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0013', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0014', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0015', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0016', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0017', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0018', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0019', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0021', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0022', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0023', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0024', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0025', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0026', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0027', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0028', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0029', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0031', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0032', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0033', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0034', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0035', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0041', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0042', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0043', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0044', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0045', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0046', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0051', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0052', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0053', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0054', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0055', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0056', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0057', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0058', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0059', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0061', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0062', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0071', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0072', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0073', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0074', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0075', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0076', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0081', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0082', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0083', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0084', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0085', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0086', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0087', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0088', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0089', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0090', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0091', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0092', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0121', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0122', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0123', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0124', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0125', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0126', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0127', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0128', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0129', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0131', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0135', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0136', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0235', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0236', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0330', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0331', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0421', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0422', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0423', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0424', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0425', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0426', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0427', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0428', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0429', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0430', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0431', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0435', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0436', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0521', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0522', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0523', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0524', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0525', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0526', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0527', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0528', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0529', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0530', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MON0531', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MOVED', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2222', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2223', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2282', 5, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2283', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2295', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MQM2296', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MSGE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSIPOSListener.Down', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSIPOSListener.Longmsg', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSIPOSListener.Shutdown', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSIPOSListener.Switch', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSIPSender.Down', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSListener.Down', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^MVSSender.Down', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NDMP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NKEY', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NO PATH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NOFB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NOOT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NPDL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NPOQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NQRE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NSDC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NTIQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NVAP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NVSC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OBAU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ODIE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OLER', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OLNA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OLST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ONLC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ONLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPC.ERROR', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPCENDED', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPCSTARTED', 0, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ORER', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ORIP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ORST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OS.Heart.Beat', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OSBL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OSCH', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OSCL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OSDN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OXHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OXLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAER', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAGE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAOD', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PART..*', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PartFail', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PATH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PATM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAUSE.PENDING', 3, 'Pause Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PAUSED', 3, 'Paused', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PBTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PCRT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PDNO', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PDO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PERA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PERS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PGM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PGUP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PIBC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PIBP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PILC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PILP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^POLU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^POLW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PRED', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PREF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PSCU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSACPU0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAIO00', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAIO01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAIR01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAPAG0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAPAG1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSAPGR1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSASRV0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSASRV1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSASSR1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBCPU1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBIO00', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBIO01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBPAG0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBPAG1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBSRV0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSBSRV1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCHA01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCPU00', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCPU01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCPU02', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCPU03', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCQD01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCSA01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCSA02', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCSA03', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSCSM01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSDEV01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSDIOQ0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSDNR01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSDOM01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSDV8I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSENQ01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSFIX01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSJET01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSJET02', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSJSU01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSJSU02', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSJVR01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSLCQ01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSMTP01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSNRQ01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSNRQP1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSOUT01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSPAG01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSPGQ01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSPGSR1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSPSRV0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSPSRV1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSREP01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSRES01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSRSU01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSMF01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSMF02', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSMF03', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSMF04', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSMF09', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSPA01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSSWP01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTCPU1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTIO00', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTIO01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTPAG0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTPAG1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTSRV0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSTSRV1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSWDLY0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSWOBJ0', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSWRT00', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^PWSWTO01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q.LIMIT.EXCEED', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STABRT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STCTHD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STCTHW', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STINDT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STMEOM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STMEOT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q3STSIGN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q9STCTR6', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q9STCTRK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q9STCTRN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Q9STCTRS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACGET', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACHRF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACHWF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACIMW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACRIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBACSWS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGAMD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGAMN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGASW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGAWC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGAXD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGL2F', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAY', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLAZ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLCN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLCT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLGT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLMD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLOS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLRC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLRF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLSU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLSW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLWC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLWF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBGLXD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTARF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTAWF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTCBA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDMC', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDPF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDPP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDSO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDWT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTDWV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTHPA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTHPL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTHRF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTHWF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTIMW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTJIS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTLIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTLPF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTLPP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTMAX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTMIG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTPIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTPL1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTPL2', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTPQF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTPWS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTREE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTRIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTRPI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTRTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTSEQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTSIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTSPD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTSPP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTSWS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTVPA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWBVQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWDRP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWEE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWFD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWFF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWFM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWKPD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTWPI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTXFL', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTXFV', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QBSTXIS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTCSTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTHWAT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTHWDT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTQDBT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTQMIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTRSAT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTRSSU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QDSTWSTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QIFAAIET', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QIFAAITT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISECTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISEDBDL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISEDFAL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISEFAIL', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISEKTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTCOLS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTRHIG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTRLLM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTRMAX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTRPLM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QISTRSTG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTRACT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTRARH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTRBUF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTTVC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTWTB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QJSTWUR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACBRBF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACBROW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACBTBF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACCBLB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACCIEL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACCNVQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACRBND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACSQLR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLACSQLS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTBRBF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTBROW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTBTBF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTCBLB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTCNVQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTRBND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTSQLR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QLSTSQLS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QM70-10', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QOACLOBV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACAWTE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACAWTI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACAWTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACAWTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACAWTW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACSCT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QPACSQLC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QS.*IMW3536I', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QS.*IMW3540I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QS.*IMW3541I', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QS.*IMW3542E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTABIND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTABINDA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTAUTOBA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTDSDRN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTDSOPN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTGADRTA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTGSDRTA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTGSPEQW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTINVRID', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTMAXDS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTMAXPB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTPCCT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTPKABND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTSLWDD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXACLUN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXADEA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXADRUN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXALES', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXALEX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXANPL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXASLOC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QTXATIM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QUEUEFULL', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254CC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254DE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254DR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254RD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254RF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254RH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254RN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254RS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254TC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254TE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254TR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254WC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254WF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254WH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QW0254XR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACABRT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACAWTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACAWTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACAWTW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACCOMM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACTRET', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWACTRTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWSDCKPT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QWSDSCA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCALLAB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCALLRJ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCALLTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCASCDP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCAUDAB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCAUDRJ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXCAUDTO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXDEGBUF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXDEGCUR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXDEGENC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXDEGESA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXINCRB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXMAXDEG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXMRMIAP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXNSMIAP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXREDGRP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXROWTRG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXSTLOBV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXSTTRG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^QXTRGERR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RCPU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^REDISC.ACTIVE', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^REDISC.INACTIVE', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^REDISC.OK', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RELM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RESTART', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Rising', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0050', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0100', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0110', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0150', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0160', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0170', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0180', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0190', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0200', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0210', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0220', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0230', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0240', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0250', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0260', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0270', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0280', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0290', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0300', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0310', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0320', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0330', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0340', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0350', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0360', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0370', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0380', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0390', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0400', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0410', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0420', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0430', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0440', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0450', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0460', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0480', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0510', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0530', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0570', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0580', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0590', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0600', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0630', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0640', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0680', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0690', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0700', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0710', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0720', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0730', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0740', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0750', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0760', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0770', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0780', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0790', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0800', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0810', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0820', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0830', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0840', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0850', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0860', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0870', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0880', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0890', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0900', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0910', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0920', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0930', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0940', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0950', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0960', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0970', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0980', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM0990', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM1000', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM1010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM1020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RM1030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMTH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RSRV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RULECMD', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RULETIME', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RUNNING', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SAPW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SARWBAC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SBGLAR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SBGLMR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SBGLXR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SBRBUTP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCHEDULED', 0, 'Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCHV', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCNP-11', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCRJ-11', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCRJ-12', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SCTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDCOM12R', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDCOM12S', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDDFTOTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDIFITOT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDINUSEC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDISMFBF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDITOTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDMP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDNO', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDROL12R', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDROL12S', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDSTRAN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDSTTOTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTNA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTNW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTPFL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTSUS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTOTWF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTSCRNW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SDTSCRSW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SERCTLR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SERDBLR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SERPTLR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25950', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25951', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25952', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25953', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25954', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25960', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25961', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25962', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25963', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25964', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25965', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON25966', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26201', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26202', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26203', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26204', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26205', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26206', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26207', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26208', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26209', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26210', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26211', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26212', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26213', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26214', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26215', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26216', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26217', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26218', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26219', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26220', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26221', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26222', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26223', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26224', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26225', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26226', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26227', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26228', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26229', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26230', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26231', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26232', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26233', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26234', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26235', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.TMON26236', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV1.U', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.2', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.3', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.4', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.6', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25950', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25951', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25952', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25953', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25954', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25960', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25961', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25962', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25963', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25964', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25965', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON25966', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26201', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26202', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26203', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26204', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26205', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26206', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26207', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26208', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26209', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26210', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26211', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26212', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26213', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26214', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26215', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26216', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26217', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26218', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26219', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26220', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26221', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26222', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26223', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26224', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26225', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26226', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26227', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26228', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26229', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26230', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26231', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26232', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26233', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26234', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26235', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.TMON26236', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV2.U', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.1', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.2', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.3', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.4', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.5', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.6', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25950', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25951', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25952', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25953', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25954', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25960', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25961', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25962', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25963', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25964', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25965', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON25966', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26201', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26202', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26203', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26204', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26205', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26206', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26207', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26208', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26209', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26210', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26211', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26212', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26213', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26214', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26215', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26216', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26217', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26218', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26219', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26220', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26221', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26222', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26223', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26224', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26225', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26226', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26227', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26228', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26229', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26230', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26231', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26232', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26233', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26234', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26235', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.TMON26236', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEV3.U', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEVC', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEVI', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SEVW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.R', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.R', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.U', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.U', 3, 'Problem', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.V', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SHOUT.V', 5, 'Problem', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SIRD-11', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SLCLKET', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SLLPSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SLOG', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SLOT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SLRSUSP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SM50-10', 0, 'Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-12', 0, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-15', 3, 'BATC.Cancelled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-18', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-19', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-20', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-21', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMF0-22', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMGH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SPO6-10', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerCache - Avg. Free Page Scan', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerCache Hit Ratio', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerI/O - Batch Average Size', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerI/O - Batch Max Size', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerI/O - Page Reads/sec', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SQLServerUser Connections', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH2', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH3', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH4', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH6', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH7', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRH8', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL2', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL3', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL4', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL6', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL7', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRL8', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT1', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT2', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT3', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT4', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT5', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT6', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT7', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRT8', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SRTTERM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSCDCL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSCDDL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSCDML', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSM0-33', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSM0-34', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSM0-35', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSM0-41', 5, 'Problem', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSRT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SSTOTT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^START.PENDING', 3, 'Start Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STARTED', 0, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STARTED2', 3, 'Starting', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STOP.PENDING', 3, 'Stop Pending', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STOPPED', 0, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STOPPING', 0, 'Stopping', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STRU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STRW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^STUCK', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SUSL', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SVSY', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SVTK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SVTR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SWER', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SWPC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^System', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TCOI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TCOT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TCPU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDBU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDBW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDCI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDQU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDSH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TDST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^THDQ', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TIMEOUT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMAX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB00001I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01002I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01003W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01004W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01005I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01006W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01007W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01008W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01009I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01010I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01011W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01012W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01101W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01102W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01103C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01104W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01105W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01114C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01115W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01116W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01117W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01118W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01119W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01120W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01121W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB01123W', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02005W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02006C', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02007W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02008C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02009W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02010I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02011W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02012W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02013I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02014W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02015W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02016W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02017W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB02018W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB04001C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB04002C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB04003C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB04004C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB04005C', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB05001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB05002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB05003W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB05004W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB06001I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB06002I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB06003I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB08001I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB08002I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB08003C', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB08003I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09002I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09003W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09004W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09005W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09006W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09007I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09008W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB09009W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB10001I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB10002I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB10003I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB10004I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB10005I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11003W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11004W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11005W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11006W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB11007W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB12001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB12002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB13001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB13002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB14001W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB14002W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMDB14003W', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TMSI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TNRS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenAutoWrap', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenAutoWrap', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenDeinsert', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenDeinsert', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenThres', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TokenThres', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TPDR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TPWT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TPWT..*', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRAN.DISABLED', 3, 'Disabled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRAN.ENABLED', 0, 'Enabled', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRCV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRDY', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRDY..*', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TRHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TSBU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TSBW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TSND', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TSSH', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TSST', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TXIQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TXN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TXQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UNAVAILABLE', 5, 'Unavailable', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UNHANDLED EVENT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UNKNOWN', 5, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Unmanaged', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UNVF', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Up', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^URPROBLEM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^UTIS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VCAS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VCIS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VDIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VEDR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VINX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VISC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VMEX', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VMLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VSLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VSRV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VTIO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VTLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VTMA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VTOC', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VUTL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VWRC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VXHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VXLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WAIT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WAIT.ON.INPUT.Q', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WAIT.RESOURCES', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WBHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WBLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WCHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WDLK', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WLCM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WLGQ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WLHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WLLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0010', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0020', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0030', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0040', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0050', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0060', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0070', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0080', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0090', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0100', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0110', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0120', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0130', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WM0140', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WSHI', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WSLO', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WSRV', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WTOR', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^WTRE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XACP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XCHN', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XCON', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XCPU', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XCSA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XDDR', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XDOM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XDPR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XECS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XESM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XGRS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XGTF', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XJCA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XJCB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XJSA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XJSB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XMCA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XMEM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XMPP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XMTA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XOLT', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XPRT', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XREP', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XRFA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XRMF', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSCA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSCB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSFR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSMA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSMF', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSMR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSOS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSPM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSQA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSRM', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSSA', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XSSB', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XTOD', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XUCA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XUCB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XUIC', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XUSA', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XUSB', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^XVCS', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Z0302I.LOJ', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Z0320I.AEOJ', 5, 'Abended', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Z0320I.BOJ', 0, 'Running', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^Z0320I.EOJ', 0, 'Completed', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^ZOMBIE', 3, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPSTBSME', 5, 'Error', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPSTBSMM', 5, 'Error', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^OPSTBSMW', 3, 'Warning', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOSTBSME', 5, 'Error', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOSTBSMM', 5, 'Error', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^AOSTBSMW', 3, 'Warning', 0);
-- TWS data source entries     @02A10
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_STARTED', 0, '', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_ENDED', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_CP UPDATED', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_ERROR_OPERATION', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_LATE_OPERATION', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_LONG_DURATION', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_WAIT_ON_INPUT_Q', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_WAIT_RESOURCES', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_OPC_ERROR', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^TWS_Q_LIMIT_EXCEED', 3, '', 0);
go
--                                                                        96@11A
-- Severity for RMF events which are supported out-of-the box by
-- Tivoli Event Pump for z/OS
--
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LCSFRAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LCSUIC', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HCSANRL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HCSAUTL', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LCSAAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HECSANRL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HECSAUTL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LECSAAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HENQDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HESQANRL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HESQAUTL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LESQAAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HESFRAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HESMIGRA', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HHSMDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HHSMDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HIOACTR', 2, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HIODIORR', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HIODJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HIODLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HIODLYRQ', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LIOUSNG', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LIOWFLW', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HJESDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HMVACTU', 2, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HMVDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HMVDLY', 5, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HMVUNK', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HMVUSER', 0, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LMVTXNR', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LMVUJOB', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LMVUSNG', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LMVWFLW', 5, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_MVEXCVL', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HOPRDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HOPRDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRLPAR', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRSRB', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRTCB', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HPRTOTU', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LPRUSNG', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LPRUSNGJ', 3, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LPRWFLW', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSQANRL', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSQAUTL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_LSQAAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSTDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSTDLYJ', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSSDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HSSDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HXCFDJOB', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_HXCFDLY', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ACTUSRS', 2, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#NUMUSRS', 0, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#PCTIDLE', 2, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#USJOBS', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSAPU', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSAPA', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSAFD', 0, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSFAV', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSUIC', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSFI', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSFROL', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#CSPAF', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#IOACT', 2, 'Activity', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#DELJOBS', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#DELIO', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#IOUSJOBS', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#USPCT', 2, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ECSAPU', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ECSAPA', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ECSAPU', 0, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ENQDELJ', 3, 'Delay', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ESQAPU', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ESQAPA', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#ESQAFD', 0, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#PARTUTL', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#TOTUTIL', 2, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#PROCUSR', 3, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#PROCONL', 0, 'Service', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#SQAPU', 5, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#SQAPA', 3, 'Usage', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_#SQAFD', 0, 'Usage', 1);
go
-- -----------------------------------------------------------------------------
-- Legacy RMF events mapping
-- ----------------------------------------------------------------------------- 
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_TRUE', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_FALSE', 0, '', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RMF_ERROR', 5, '', 0);
go
--
-- CPSM data source entrieds  @05A6
--
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_VLS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_LS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_HS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_VHS', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_LW', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CPSM_HW', 3, '', 0);
go
--
-- New DB2 events ID with the new product prefix  @06A17
--
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ$DBUG', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ420I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ452I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ452I.DOWN', 5, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ452I.UP', 0, 'Active', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ497I', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ648', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ686', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ718I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ718I.NOK', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ719I', 0, 'Unknown', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ743', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZ745E', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZBLK01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZBPM01', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZBPM02', 3, 'Inactive', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^GPZBSP01', 3, '', 0);
go
--
-- New SMS events ID                              @07A10
--
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CUNIT_LVOL', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^CUNIT_RLD', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VOL_IOERR',5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^VTOC_RED', 5, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NEW,DISABLE IGD010I',3, 'DISABLE,NEW', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^NEW,QUIESCE IGD010I',3, 'QUIESCE,NEW', 1);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^RCOPY', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMS_ERROR', 3, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMS_FALSE', 0, '', 0);
insert into alerts.zos_severity_msgstate_lookup (EventID, Severity, MsgState, IsMessage) values('^SMS_TRUE', 5, '', 0);
go
--
-- Create trigger groups for the zos trigger code.
create or replace trigger group zos_triggers;
go

-- -----------------------------------------------------------------------------
-- Add triggers to the lookup tables.
-- -----------------------------------------------------------------------------
create or replace trigger zos_severity_msgtype_lookup
group zos_triggers
debug FALSE
priority 1
comment 'z/OS Lookup of Severity and Message State for zos alerts only.'
before insert on alerts.status
for each row
when new.AlertGroup = 'TBSMV3_SOURCE390'
declare
now utc;
begin

if(new.ZOS_IsUserSeverity=1)
then
	-- Determine if event is a Message, Exception or Resolution
	-- Check value of action

	-- If Message ( all zos action code should colapse to '03' it it truely is a message).
	if( new.ZOS_Action = '03' ) -- message
	then

		for each row tbl2 in alerts.zos_severity_msgstate_lookup where tbl2.IsMessage = 1
		  and new.ZOS_EventID like tbl2.EventID
		begin
			set new.Severity = tbl2.Severity;
			set new.ZOS_MsgState = tbl2.MsgState;
		end;

	end if;

	--  If Exception ( all zos action code should colapse to '04' it it truely is an exception alert).
	if( new.ZOS_Action = '04' ) -- exception
	then

		-- Lookup Severity based on EventID (using like statement)
		-- Insert the event with new Severity and State
		for each row tbl in alerts.zos_severity_msgstate_lookup where  tbl.IsMessage = 0 and new.ZOS_EventID like tbl.EventID
		begin
			set new.Severity = tbl.Severity;
		end;
	end if;

end if;

end

go

create or replace trigger zos_clear
group zos_triggers
debug FALSE
priority 1
comment 'Aggregate server clearing for zos alerts only.'
after insert on alerts.status
for each row
when new.AlertGroup = 'TBSMV3_SOURCE390'
declare now utc;
begin

-- If Message ( all zos action code should colapse to '03' if the event is a message).
if( new.ZOS_Action = '03'  and new.Severity = 0) -- message
then

	-- High level clear from a monitor sucah as SA/390 or OPS/MVS.
	if( new.Node <> '' and new.ZOS_ResourceName <> '' and new.ZOS_SubResourceName = '' and new.ZOS_SubResourceType = '' )
	then
	  update alerts.status set Severity = 0 where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName
	end if;

	-- Low level clear from a subtype resource.
	if( new.Node <> '' and new.ZOS_ResourceName <>'' and new.ZOS_SubResourceName <> '' and new.ZOS_SubResourceType <> '' )
	then
	  update alerts.status set Severity = 0 where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName and  ZOS_SubResourceName = new.ZOS_SubResourceName and ZOS_SubResourceType= new.ZOS_SubResourceType
	end if;

end if;

-- If Resolution ( all zos action codes should colapse to '05' or ('04' and 'OK') if it truely is a resolution alert).
if( new.ZOS_Action = '05' or (new.ZOS_Action = '04' and new.Summary = 'OK') )
then

	-- High level clear from a monitor such as SA/390 or OPS/MVS.
	if( new.Node <> '' and new.ZOS_ResourceName <> '' and new.ZOS_SubResourceName = '' and new.ZOS_SubResourceType = '' )
	then
	  update alerts.status set Severity = 0,Summary = 'Resolved: ' + new.Summary where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName  and  ZOS_EventID = new.ZOS_EventID and Summary not like '^.*Resolved:.*'
	end if;


	-- Low level clear from a subtype resource monitor such as DB2. IMS or CICS.
	if( new.Node <> '' and new.ZOS_ResourceName <>'' and new.ZOS_SubResourceName <> '' and new.ZOS_SubResourceType <> '' )
	then
	   update alerts.status set Severity = 0,Summary = 'Resolved: ' + new.Summary where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName and  ZOS_SubResourceName = new.ZOS_SubResourceName and ZOS_SubResourceType= new.ZOS_SubResourceType and  ZOS_EventID = new.ZOS_EventID and Summary not like '^.*Resolved:.*'
	end if;

end if;

end
go


create or replace trigger zos_deduplication
group zos_triggers
debug FALSE
priority 1
comment 'Aggregate server deduplication processing for zos alerts only.'
before reinsert on alerts.status
for each row
when old.AlertGroup = 'TBSMV3_SOURCE390'
declare
now utc;
begin

-- Assign the z/OS severity value first.
if(new.ZOS_IsUserSeverity=1)
then
	-- Determine if event is a Message, Exception or Resolution
	-- Check value of action

	-- If Message ( all zos action code should colapse to '03' it it truely is a message).
	if( new.ZOS_Action = '03' ) -- message
	then

		for each row tbl2 in alerts.zos_severity_msgstate_lookup where tbl2.IsMessage = 1
		  and new.ZOS_EventID like tbl2.EventID
		begin
			set old.Severity = tbl2.Severity;
			set old.ZOS_MsgState = tbl2.MsgState;
		end;

	end if;

	--  If Exception ( all zos action code should colapse to '04' it it truely is an exception alert).
	if( new.ZOS_Action = '04' ) -- exception
	then

		-- Lookup Severity based on EventID (using like statement)
		-- Insert the event with new Severity and State
		for each row tbl in alerts.zos_severity_msgstate_lookup where  tbl.IsMessage = 0 and new.ZOS_EventID like tbl.EventID
		begin
			set old.Severity = tbl.Severity;
		end;
	end if;

end if;

-- Do z/OS clering next
-- If Message ( all zos action code should colapse to '03' if the event is a message).
if( new.ZOS_Action = '03'  and old.Severity = 0) -- message
then

	-- High level clear from a monitor sucah as SA/390 or OPS/MVS.
	if( new.Node <> '' and new.ZOS_ResourceName <> '' and new.ZOS_SubResourceName = '' and new.ZOS_SubResourceType = '' )
	then
	  update alerts.status set Severity = 0 where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName
	end if;

	-- Low level clear from a subtype resource.
	if( new.Node <> '' and new.ZOS_ResourceName <>'' and new.ZOS_SubResourceName <> '' and new.ZOS_SubResourceType <> '' )
	then
	  update alerts.status set Severity = 0 where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName and  ZOS_SubResourceName = new.ZOS_SubResourceName and ZOS_SubResourceType= new.ZOS_SubResourceType
	end if;

end if;

-- If Resolution ( all zos action codes should colapse to '05' or ('04' and 'OK') if it truely is a resolution alert).
if( new.ZOS_Action = '05' or (new.ZOS_Action = '04' and new.Summary = 'OK') )
then

	-- High level clear from a monitor such as SA/390 or OPS/MVS.
	if( new.Node <> '' and new.ZOS_ResourceName <> '' and new.ZOS_SubResourceName = '' and new.ZOS_SubResourceType = '' )
	then
	  update alerts.status set Severity = 0,Summary = 'Resolved: ' + new.Summary where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName  and  ZOS_EventID = new.ZOS_EventID and Summary not like '^.*Resolved:.*'
	end if;


	-- Low level clear from a subtype resource monitor such as DB2. IMS or CICS.
	if( new.Node <> '' and new.ZOS_ResourceName <>'' and new.ZOS_SubResourceName <> '' and new.ZOS_SubResourceType <> '' )
	then
	   update alerts.status set Severity = 0,Summary = 'Resolved: ' + new.Summary where Node = new.Node and ZOS_ResourceName = new.ZOS_ResourceName and  ZOS_SubResourceName = new.ZOS_SubResourceName and ZOS_SubResourceType= new.ZOS_SubResourceType and  ZOS_EventID = new.ZOS_EventID and Summary not like '^.*Resolved:.*'
	end if;

end if;

-- Do base dedupe last...
-- set old.Tally = old.Tally + 1;        --@03C1
set old.LastOccurrence = new.LastOccurrence;
set old.StateChange = getdate();
set old.InternalLast = getdate();
set old.Summary = new.Summary;
set old.AlertKey = new.AlertKey;

end
go
